from abc import ABC, abstractmethod
from enum import Enum


class InferenceMode(str, Enum):
    WHOLE_IMAGE = 'whole_image'
    ALL_ROIS = 'all_rois'
    SELECTED_ROIS = 'selected_rois'


class Runtime(str, Enum):
    ONNX_RUNTIME = 'onnxruntime'
    TENSORRT = 'tensorrt'


class BaseModel(ABC):

    @abstractmethod
    def preprocess(self, item):
        pass

    @abstractmethod
    def predict(self, input_batch):
        pass

    @abstractmethod
    def postprocess(self, prediction_output, item):
        pass

    @abstractmethod
    def destroy(self):
        pass
